LOG_IN = '/v2/auth/signin'
LOG_IN_APPLE = '/v2/auth/signin/apple'
LOG_IN_GOOGLE = '/v2/auth/signin/google'
LOG_IN_MAIL_RU = '/v2/auth/signin/mailru'
LOG_IN_YANDEX = '/v2/auth/signin/yandex'
LOG_OUT = '/v1/auth/signout'
LOG_OUT_ALL = '/v1/auth/signout/all'
CHANGE_PASSWORD = '/v1/auth/change_password'
CREATE_ACCOUNT = '/v2/auth/signup'
IS_LOGIN_CAPTCHA_REQUIRED = '/v2/auth/signin/recaptcha_required'
LOGIN_HISTORY = '/v2/auth/signin/history'
RESET_PASSWORD = '/v1/auth/reset_password'
RESET_PASSWORD_REQUEST = '/v1/auth/reset_password_request'
REQUEST_SMS_CODE = '/v2/auth/phone/code'
VERIFY_SMS_CODE = '/v2/auth/phone/code'
