MARK_SEARCH_SEEN = '/saved-search/v1/accounts/{account_id}/searches/{search_id}/views'
DELETE_SEARCH = '/saved-search/v1/accounts/{account_id}/searches/{search_id}'
GET_FAVORITE_SEARCHES = '/saved-search/v1/accounts/{account_id}/searches'
SAVE_SEARCH = '/saved-search/v1/accounts/{account_id}/searches'
