API_URL = 'https://api.kufar.by'
CRE_API_URL = 'https://cre-auth.kufar.by'
BAPI_URL = 'https://bapi.kufar.by/api'

BASE_HEADERS = {
    'user-agent': 'Kufar/v3.0.1/13/Xiaomi/Mi 9T Pro',
    'x-app-name': 'Android Kufar',
    'x-app-version': 'v3.0.1',
    'x-device-id': '45f44584-588f-4a92-959e-ad3416a88c28'
}